<?php

declare(strict_types=1);

namespace Drupal\hook_event\Event;

use Drupal\Component\Utility\NestedArray;

/**
 * Provides the event class used for preprocess hooks.
 */
class HookPreprocessEvent extends HookEvent {

  /**
   * {@inheritdoc}
   */
  public function __construct(string $hook, array $arguments = []) {
    parent::__construct($hook, [
      'variables' => $arguments,
      'raw_variables' => $arguments,
    ]);
  }

  /**
   * Setter for the variables.
   *
   * @param array $variables
   *   The render array variables.
   */
  public function setVariables(array $variables): void {
    $this->setArgument('variables', $variables);
  }

  /**
   * Getter for the variables.
   *
   * @return array
   *   The render array variables.
   */
  public function getVariables(): array {
    return $this->getArgument('variables') ?? [];
  }

  /**
   * Getter for the raw (untouched) variables.
   *
   * Useful in case of verifying the changes on the original
   * array with the variables.
   *
   * @return array
   *   The render array variables.
   */
  public function getRawVariables(): array {
    return $this->getArgument('raw_variables');
  }

  /**
   * Merge new variables to the existing ones.
   *
   * @param array $variables
   *   The render array variables.
   */
  public function merge(array $variables): void {
    $variables = NestedArray::mergeDeep($this->getVariables(), $variables);
    $this->setVariables($variables);
  }

}
